;;; -*- lisp -*-

;;;; * Default UCW startup file

;;;; This file is meant to be loaded by ucwctl(1), but you can use it
;;;; as a general "startup ucw" file as well.  In this case, you
;;;; should customize this script to load/prepare your application.


(in-package :common-lisp-user)

;;;; * CMUCL specific hacks

#+cmu
(defun init-cmu-mp ()
  ;; this isn't strictly necessary, but scheduling feels very coarse
  ;; without startup-idle-and-top-level-loops, leading to answer delays
  ;; of about 1s per request.
  (unless (find-if
           #'(lambda (proc)
	       (string= (mp:process-name proc) "Top Level Loop"))
           (mp:all-processes))
    (mp::startup-idle-and-top-level-loops)))

#+cmu
(init-cmu-mp)

;;;; * Loadup dependencies

;;;; Load arnesi first so we can set arnesi::*call/cc-returns* before
;;;; ucw is compiled and loaded.
(asdf:oos 'asdf:load-op :arnesi)
(setf arnesi::*call/cc-returns* nil
      arnesi:*warn-undefined* t)

;;;; Load up UCW itself
(asdf:oos 'asdf:load-op :ucw)

(in-package :it.bese.ucw-user)

#+(and sbcl sb-unicode)
(setf (external-format-for :slime) :utf-8-unix
      (external-format-for :url)   :utf-8
      (external-format-for :http-emacsen)  :utf-8-unix
      (external-format-for :http-lispish)  :utf-8)

;;;; Load the config file if present, otherwise set the *ucw-systems*
;;;; and *ucw-applications* variables
;;;(Actually, I don't want to force loading the apps until after all
;;; servers have been created. So just load the config file manually instead.)
;(if *ucw-config-file*
;    (load-config-file)
;    (load-applications))
(load (merge-pathnames *ucw-config-file* cl-user::*start-dir*))

;;;; Let there be swank.
;;;;
;;;; This will allow emacs to attach to the same lisp process that's serving
;;;; http requests. This way the lisp apps may be modified in emacs while the
;;;; server is running and the changes can be immediately seen in the browser.
#-clisp (ucw:start-swank *ucw-swank-port*)
;;;; Since clisp is not multithreaded, all servers must be started up a bit differently.
#+clisp (swank:create-server :dont-close t :style :fd-handler) 

;;;; * Startup the lisp application server.
;(trace (ucw:create-server :step-if t))
(ucw:create-server :backend `(,*ucw-backend-type* :host ,*ucw-backend-host*
						  :port ,*ucw-backend-port*)
		    ;:applications       *ucw-applications*  ;(eval *ucw-applications*)
		   :inspect-components *ucw-inspector*
		   :debug-on-error     *ucw-debugger*
		   :server-class       *ucw-server-class*
		   :log-root-directory (make-pathname
					:directory '(:absolute "var" "log" "ucw" ))
					;*ucw-log-root-directory*
		   :log-level (symbol-value *ucw-log-level*)

		   ;; start the server after creating it, but wait to actually start
		   ;; listening and serving requests. (See host-serve-events)
		   :start-p t    

		   ;; Search alternate url base "/" for static files 
		   ;; such as favicon.ico, dojo.js, etc.
;; Now static files will be searched in the "usual" places (i.e., at '/'), 
;; instead of using the '/hello/' url prefix. This new url prefix will be used
;; for each of the wwwroots that this server searches.
		   :search-alt-url-base t )

; Don't load this until after finish loading applications
; because this would cause clisp to block.
;(araneida:host-serve-events)

;; Copyright (c) 2003-2006 Edward Marco Baringer
;; Copyright (c) 2006 Luca Capello http://luca.pca.it <luca@pca.it>
;; All rights reserved.
;;
;; Redistribution and use in source and binary forms, with or without
;; modification, are permitted provided that the following conditions are
;; met:
;;
;;  - Redistributions of source code must retain the above copyright
;;    notice, this list of conditions and the following disclaimer.
;;
;;  - Redistributions in binary form must reproduce the above copyright
;;    notice, this list of conditions and the following disclaimer in the
;;    documentation and/or other materials provided with the distribution.
;;
;;  - Neither the name of Luca Capello, Edward Marco Baringer, nor
;;    BESE, nor the names of its contributors may be used to endorse
;;    or promote products derived from this software without specific
;;    prior written permission.
;;
;; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
;; "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
;; LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
;; A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT
;; OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
;; SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
;; LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
;; DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
;; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
;; (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
;; OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
