;; load asdf (one and only one time). Load into package :asdf.
#-:asdf (load "/cygdrive/c/dev/lisp/asdf")

(pushnew "/cygdrive/c/dev/lisp/systems/"              asdf:*central-registry* :test #'equal)
(pushnew "/cygdrive/c/dev/lisp/asdf-install/"         asdf:*central-registry* :test #'equal)
(pushnew "/cygdrive/c/cygwin/usr/local/asdf-install/" asdf:*central-registry* :test #'equal)

;; load "asdf-install," put in :asdf-install package.
;; this form will make sure it's loaded only once.
#-:asdf-install (asdf:operate 'asdf:load-op :asdf-install)

;; load clocc
(setq *clocc-root* "/usr/local/asdf-install/site/clocc/")
(load (concatenate 'string *clocc-root* "clocc"))
(load (translate-logical-pathname "clocc:src;cllib;base")) 
(load (translate-logical-pathname "clocc:src;cllib;htmlgen")) 
 

;; make it a little easier to read debug traces.
(declaim (optimize (speed 0) (safety 2) (space 0) (debug 3)))

;; load backend lisp http server
(asdf:oos 'asdf:load-op 'araneida)

;; load swank code so that the server can be started shortly
(load (merge-pathnames "/cygdrive/c/dev/lisp/slime/swank-loader.lisp"))

;; define directory where start script and configuration file can be found.
(defparameter cl-user::*start-dir* (merge-pathnames "/etc/ucw/"))

;; create swank and lisp application servers.
(load (merge-pathnames "start.lisp" cl-user::*start-dir*))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; load apps

(in-package :it.bese.ucw)

;; If the examples haven't already been loaded, load them.
(unless (associated-application *default-server* "/")
	(asdf:oos 'asdf:load-op :ucw.examples))
;; If the admin app hasn't already been loaded, load it.
(unless (associated-application *default-server* "/admin/")
	(asdf:oos 'asdf:load-op :ucw.admin))

;; Neither of the following two statements will work in Clisp in combination with UCW 
;; because asdf will automatically compile the file before loading it, and (load "hello") 
;; will automatically load the compiled file if it exists. Why is this a bad thing? Because
;; UCW will open up the hello.lisp file during the compilation phase and rewrite portions of
;; the code. These portions must be saved and reread later after the .fas file has been written.
;; How is it possible to save and then reread code that has been modified at compilation time?
;; Common Lisp uses the 'make-load-form' function to allow this modified code to be saved to the
;; .fas file and later reinstantiated, except 'make-load-form' interferes with the UCW 
;; interpreter (at least on Clisp).

;(asdf:oos 'asdf:load-op :hello)
;(load "hello")

;; You HAVE to specify the '.lisp' extension when using 'load' or the .fas will be loaded 
;; (if it exists).
;(let ((path (merge-pathnames 
;         (concatenate 'string 
;              it.bese.ucw-user::*ucw-applications-directory* 
;              "hello/hello.lisp"))))
;  (load path))
; Or, better yet, just use asdf's special "load-source-op," like this,
(asdf:oos 'asdf:load-source-op :hello)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; For further explanation of the following, see Vlado Tzankov's email on Bese-Devel mailing list 
;; (http://common-lisp.net/pipermail/bese-devel/2005-November/001297.html), dated Nov 19, 2005.
;; Ready to start serving http requests.
#+clisp (progn
	  (format t "# starting listener...")
	  ;; Clisp will block on this statement,
	  ;; so don't bother adding anything after this.
	  (araneida:host-serve-events))
